from spatial_networks.spatial_networks import SpatialNetwork
from spatial_networks.spatial_networks import RandomGeometricGraph
from spatial_networks.spatial_networks import StarNetwork
from spatial_networks.spatial_networks import StarAndRingNetwork

import warnings

warnings.warn(
    """
    This package is a demonstration package (for now on). It has not been tested and should not be used for important tasks.
    """
)
